@@ -33,7 +33,6 @@
 #  define KARCHIVE_DECL_DEPRECATED_NO_EXPORT KARCHIVE_NO_EXPORT KARCHIVE_DECL_DEPRECATED
 #endif
 
-/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KARCHIVE_NO_DEPRECATED
 #    define KARCHIVE_NO_DEPRECATED
@@ -42,6 +41,8 @@
 
 #define KARCHIVE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KARCHIVE_NO_DEPRECATED) && !defined(KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -85,7 +86,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54e00
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -95,7 +96,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x54e00
 #  endif
 #endif
 
@@ -104,7 +105,7 @@
 #endif
 
 #ifdef KARCHIVE_DEPRECATED
-#  define KARCHIVE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KARCHIVE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KARCHIVE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -114,21 +115,8 @@
 #else
 #  define KARCHIVE_DEPRECATED_VERSION_5_0(text)
 #endif
-
-#if KARCHIVE_DEPRECATED_WARNINGS_SINCE >= 0x55500
-#  define KARCHIVE_DEPRECATED_VERSION_5_85(text) KARCHIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KARCHIVE_DEPRECATED_VERSION_5_85(text)
-#endif
 #define KARCHIVE_DEPRECATED_VERSION_5(minor, text)      KARCHIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KARCHIVE_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION(major, minor, text)
-#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KARCHIVE_EXPORT_H */
